@@ -7,11 +7,11 @@
 #include "phpast-fwd.h"
 
 #include "parserexport.h"
-#include <QtCore/QList>
+#include <QList>
 #include <kdev-pg-list.h>
 
 
-# 58 "/build/kdevelop-php/src/kdev-php-5.3.2/parser/php.g" 1
+# 58 "/build/kdevelop-php/src/kdev-php-5.3.3/parser/php.g" 1
 
 
 #include <QtCore/QRegularExpression>
@@ -26,7 +26,7 @@ namespace Php
 {
 
 
-# 92 "/build/kdevelop-php/src/kdev-php-5.3.2/parser/php.g" 1
+# 92 "/build/kdevelop-php/src/kdev-php-5.3.3/parser/php.g" 1
 
 class Lexer;
 
@@ -225,7 +225,7 @@ struct KDEVPHPPARSER_EXPORT AstNode
     qint64 startToken;
     qint64 endToken;
 
-# 147 "/build/kdevelop-php/src/kdev-php-5.3.2/parser/php.g" 1
+# 147 "/build/kdevelop-php/src/kdev-php-5.3.3/parser/php.g" 1
 
     KDevelop::DUContext* ducontext;
 
